@@ -111,13 +111,13 @@ class VizTextDraw:
         if show_shadow:
             if shadow_color is None:
                 shadow_color = self.default_shadow_color
-            draw.multiline_text((x0 + padding_left + 1, y0 + padding_top + 1),
+            draw.multiline_text((x0 + padding_left + 1, y0 - padding_top + 1),
                                 font=self.font, text=text, fill=shadow_color)
 
         # put text above rectangle
         if txt_color is None:
             txt_color = self.default_txt_color
-        draw.multiline_text((x0 + padding_left, y0 + padding_top),
+        draw.multiline_text((x0 + padding_left, y0 - padding_top),
                             font=self.font, text=text, fill=txt_color)
 
         return draw
